timeline library
Timeline motion primitives.
Classes
- HuahuaFixedExtentScrollTimeline
- A ready-to-use fixed-extent list with focus motion and an edge timeline.
- HuahuaFixedExtentSnapScrollPhysics
- Snaps a fixed-extent scrollable to item boundaries with an elastic spring.
- HuahuaMeasuredScrollTimeline
- Experimental varied-height timeline which measures natural item heights.
- HuahuaTimelineDetails
- The state and callbacks supplied to HuahuaTimelineBuilder.
- HuahuaTimelineEntry
- A point on a HuahuaTimelineScrubber.
- HuahuaTimelineScrubber
- A transient, edge-aligned timeline selector for a vertically scrolling list.
- HuahuaVariedExtentScrollTimeline
- A center-focused timeline whose item extents can differ by index.
- HuahuaVariedExtentSnapScrollPhysics
- Snaps to a supplied set of item-center scroll offsets.
Typedefs
- HuahuaTimelineBuilder = Widget Function(BuildContext context, HuahuaTimelineDetails details)
- Builds a custom timeline overlay for a scroll timeline.